This is a generator of simple, strong, memorable and easy-to-type passwords.

You can install it with `pip install pwd-generator` and use the cli version:

```

pwdgen
```

Then the output would be like:

```

6Nixe#Becokace
0Qubyby+Pomafy
7Zuxogu:Lebuwo
Zy&Jivulezexu0
```

To use it in a python code

```python

import pwdgen
print(pwdgen.generate())
```
